@@ -3,8 +3,9 @@
 import logging
 import coloredlogs
 import json
-import os
+import requests
 from datetime import datetime
+from packaging import version
 
 
 log_level = None
@@ -75,6 +76,22 @@ def preview(response, num_lines=5):
         return f'{head}\n{tail} more lines hidden'
 
 
+def check_version(installed_version):
+    log = get_logger(__name__)
+    try:
+        r = requests.get('https://api.github.com/repos/marzzzello/pytr/tags', timeout=1)
+    except Exception as e:
+        log.error('Could not check for a newer version')
+        log.debug(str(e))
+        return
+    latest_version = r.json()[0]['name']
+
+    if version.parse(installed_version) < version.parse(latest_version):
+        log.warning(f'Installed pytr version ({installed_version}) is outdated. Latest version is {latest_version}')
+    else:
+        log.info('pytr is up to date')
+
+
 class Timeline:
     def __init__(self, tr):
         self.tr = tr
@@ -221,7 +238,7 @@ class Timeline:
 
         if self.received_detail == self.num_timeline_details:
             self.log.info('Received all details')
-            os.makedirs(dl.output_path, exist_ok=True)
-            with open(os.path.join(dl.output_path, 'other_events.json'), 'w', encoding='utf-8') as f:
+            dl.output_path.mkdir(parents=True, exist_ok=True)
+            with open(dl.output_path / 'other_events.json', 'w', encoding='utf-8') as f:
                 json.dump(self.events_without_docs, f, ensure_ascii=False, indent=2)
             dl.work_responses()
